@@ -5,10 +5,11 @@ import re
 
 from typing import Any
 from dataverk.abc.base import DataverkBase
-from dataverk.utils import validators, file_functions, storage_paths
+from dataverk.utils import validators, storage_paths
 from collections.abc import Sequence
 from dataverk.connectors.storage.storage_connector_factory import StorageType
 from dataverk.resources.factory_resources import get_resource_object, ResourceType
+from dataverk.views.view_factory import get_view_object
 
 
 class Datapackage(DataverkBase):
@@ -56,7 +57,7 @@ class Datapackage(DataverkBase):
 
     def add_resource(self, resource: Any, resource_name: str = "",
                      resource_description: str = "", resource_type: str = ResourceType.DF.value,
-                     spec: dict = None):
+                     spec: dict = None) -> str:
         """
         Adds a resource to the Datapackage object. Supported resource types are "df", "remote" and "pdf".
 
@@ -72,14 +73,14 @@ class Datapackage(DataverkBase):
 
         :param resource_description: str, description of resource, default = ""
         :param spec: dict, resource specification e.g hidden, fields, format, compress, etc, default = None
-        :return: None
+        :return: path: str: resource path
         """
         resource = get_resource_object(resource_type=resource_type, resource=resource,
                                        datapackage_path=self.datapackage_metadata.get("path"),
                                        resource_name=resource_name,
                                        resource_description=resource_description, spec=spec)
 
-        resource.add_to_datapackage(self)
+        return resource.add_to_datapackage(self)
 
     def add_view(self, name: str, resources: Sequence, title: str = "", description: str = "", attribution: str = "",
                  spec_type: str = "simple", spec: dict = None, type: str = "", group: str = "",
@@ -101,25 +102,11 @@ class Datapackage(DataverkBase):
         :param metadata:
         :return: None
         """
-        if spec is None:
-            spec = {"type": type,
-                    "group": group,
-                    "series": series}
+        view = get_view_object(name=name, resources=resources, description=description, attribution=attribution,
+                               spec_type=spec_type, spec=spec, type=type, group=group,
+                               series=series, row_limit=row_limit, metadata=metadata)
 
-        view = {'name': file_functions.remove_whitespace(name),
-                'title': title,
-                'description': description,
-                'attribution': attribution,
-                'resources': resources,
-                'specType': spec_type,
-                'spec': spec,
-                'transform': {
-                    "limit": row_limit
-                },
-                'metadata': metadata
-                }
-
-        self.datapackage_metadata["views"].append(view)
+        view.add_to_datapackage(self)
 
     def _get_dp_title(self, metadata):
         try:
