@@ -1,5 +1,3 @@
-from dataverk.utils.file_functions import url_encode
-
 from dataverk.utils import file_functions
 
 from dataverk.resources.base_resource import BaseResource
@@ -21,10 +19,11 @@ class JSONResource(BaseResource):
         self._schema = self._get_schema()
 
     def formatted_resource_name(self):
-        return url_encode(self._resource_name)
+        return file_functions.remove_whitespace(self._resource_name)
 
     def _resource_path(self):
         return self._create_resource_path(
+            self._datapackage_path,
             self.formatted_resource_name(),
             self._fmt,
             False
@@ -32,7 +31,7 @@ class JSONResource(BaseResource):
 
     def _get_schema(self):
         return {
-            "name": self._resource_name,
+            "name": self.formatted_resource_name(),
             "description": self._resource_description,
             "path": self._resource_path(),
             "format": self._fmt,
@@ -46,7 +45,7 @@ class JSONResource(BaseResource):
         :param dp: Datapackage object to append resources to
         :return: path: str: Path to resource
         """
-        resource = self._schema
-        resource["data"] = self._resource_data
-        dp.resources.append(resource)
-        return resource.get("path")
+        formatted_resource_name = self._schema.get("name")
+        dp.resources[formatted_resource_name] = self._schema
+        dp.resources[formatted_resource_name]["data"] = self._resource
+        return self._schema.get("path")
